YayMounts = LibStub("AceAddon-3.0"):NewAddon("YayMounts","AceConsole-3.0", "AceEvent-3.0")
AceGUI = LibStub("AceGUI-3.0")

local options = {
	name="YayMounts",
	handler = YayMounts,
	type = "group",
	args = {
		enable = {
			type = "execute",
			name = YayMountsLocale.Misc.optionsGUIButton,
			func = "Frames",
		},
	}
}

local version = "1.4.1"
local t, aspectTable = {}, {13165, 82661, 5118, 13159, 20043}
local Z = false
local onGroundMount, mountUsed, currentTab, currentSubTab
local _, class = UnitClass("player")

local defaults = { 
	char = { 
		settings = {
			["ER"] = true, --emptyrandom: use random mount if none selected
			["FFP"] = true, --Druid: Use flight form with priority
			["TTT"] = false, --Travel to Travel, no human form. Mostly for pvp.
			["MTFF"] = false, --Druid: When flying mounted shift directly to flight form
			["CFI"] = true, --Druid: Cat Form Indoors (with 2/2 Feral Swiftness)
			["FBP"] = false, --Prioritize flying broom, even over Flight form
			["Remount"] = false, --Remount from ground->flying with 1 button
			["HM"] = false, -- Has Mount
			["NDWF"] = false, -- No Dismount while Flying. Safe!
			["FFM"] = true, --Force Flying Mount (in ground areas)
			["UA"] = true, --Hunter: Use aspect swapping
			["UA2"] = true, --Hunter: Use secondary aspect swapping
			["AIC"] = true, --Hunter: Use aspect swapping in combat
			["HA1"] = 1, -- Aspect 1
			["HA2"] = 2, -- Aspect 2
			["SHA1"] = 4, -- Sec. Aspect 1
			["SHA2"] = 3, -- Sec. Aspect 2
			["PMLS"] = true, --Priest/Mage: Levitate/Slowfall
			["SMIFO"] = false, --Only use scaling mounts in flyable areas
		},
		misc = {
			["OGM"] = false, --on ground mount
			["CV"] = 1.0, --Current version
			["RACE"] = "Human",
			["DBSize"] = 0, -- Database size
		},		
		mounts = {
			['*'] = {
			},
		},
	}
}

function YayMounts:OnInitialize() 
	self.db = LibStub("AceDB-3.0"):New("YayMountsDB", defaults)
	local ymOptions = LibStub("AceConfigRegistry-3.0")
	ymOptions:RegisterOptionsTable("YayMounts",options)
	self.ymOpFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("YayMounts","YayMounts")
	self:RegisterChatCommand("ym", "ChatCommand")
	self:RegisterChatCommand("yaymounts", "ChatCommand")
end

function YayMounts:ChatCommand(input) --Chat command function
	if input == "reload" or input == "rl" then
		YayMounts:ReSort()
		self:Print(YayMountsLocale.Misc.mountsReloaded)
		
	--elseif input ~= "" then
		--self:Print(YayMounts:GetMounts("settings", input))
		
	else
		YayMounts:Frames("tab1")
	end
end

function YayMounts:OnEnable()-- addon enabled
	local _, race = UnitRace("player")
	local i = 0
	for k,v in pairs(YayMountsType["Mounts"]) do
		i = i+1
	end
		
	if self.db.char.misc["CV"] ~= version or self.db.char.misc["RACE"] ~= race or i ~= self.db.char.misc["DBSize"] then
		self.db.char.misc["RACE"] = race
		YayMounts:ReSort()
		self.db.char.misc["CV"] = version
		self.db.char.misc["DBSize"] = i
	end

	YayMounts:MapOverrides()
 	
	self:RegisterEvent("UPDATE_BINDINGS", "MapOverrides")
	self:RegisterEvent("COMPANION_LEARNED", "EventHandler")
	
	--if class == "DRUID" or class == "SHAMAN" or class == "HUNTER" or class == "PRIEST" or class == "MAGE" then
		self:RegisterEvent("PLAYER_REGEN_DISABLED", "EventHandler")
		self:RegisterEvent("PLAYER_REGEN_ENABLED", "EventHandler")
	--end
	
	if race == "Worgen" and UnitLevel("player") < 21 then
		self:RegisterEvent("PLAYER_LEVEL_UP", "EventHandler")
	end
end
--------------------------------------------------------------
--database handling and creation functions
--------------------------------------------------------------
function YayMounts:ReSort()
	local tempTable = {}
	local tempTable2 = {}
	
	for k,v in pairs(self.db.char.mounts) do
		tempTable2[k] = self.db.char.mounts[k][4]
		self.db.char.mounts[k][1] = nil
		self.db.char.mounts[k][2] = nil
		self.db.char.mounts[k][3] = nil
		self.db.char.mounts[k][4] = nil
	end
	
	YayMounts:SortMounts(tempTable2)
end

local function IsUsableS(spellID)
	local bool, _ = IsUsableSpell(YayMounts:SpellToName(spellID))
	return bool
end

local function IsUsableM(MountSID)
	for q=1, GetNumCompanions("MOUNT"), 1 do
		local _,_,S,_,_ = GetCompanionInfo("Mount", q)
		if S == MountSID then
			return true
		end
	end
	return false
end

function YayMounts:SpellToName(spell) --converts spell ID to Name
	local name = GetSpellInfo(spell)
	return name
end

function YayMounts:ItemToName(item)
	local name = GetItemInfo(item)
	return name
end

function YayMounts:GetMounts(info, key)
	if info == "mounts" then
		return self.db.char.mounts[key][4]
	elseif info == "settings" then
		return self.db.char.settings[key]
	end
end

function YayMounts:SetMounts(info, key, state)
	if info == "mounts" then
		self.db.char.mounts[key][4] = state
		
	elseif info == "settings" then
		if key == "Remount" then
			self.db.char.misc["OGM"] = state
			self.db.char.settings[key] = state
		else
			self.db.char.settings[key] = state
		end
	end
end

function YayMounts:ClearMounts(mountType)-- clear all mounts
		for k,v in pairs(self.db.char.mounts) do
			if self.db.char.mounts[k][3] == mountType then
				self.db.char.mounts[k][4] = false
				t[k]:SetValue(false)
			end
		end
end

function YayMounts:SelectAllMounts(mountType)-- select all mounts
		for k,v in pairs(self.db.char.mounts) do
			if self.db.char.mounts[k][3] == mountType then
				self.db.char.mounts[k][4] = true
				t[k]:SetValue(true)
			end
		end
end

function YayMounts:BuildList(mountType)--Builds and draws the checkboxes for the opened tab

	t = {}
 
	if mountType == "pets" then
		for q=1, GetNumCompanions("CRITTER"), 1 do
			local _,N,S,I,_ = GetCompanionInfo("CRITTER", q)
			t[S] = AceGUI:Create("CheckBox")
			t[S]:SetImage(I)
			t[S]:SetLabel(N)
			t[S]:SetValue(YayMounts:GetMounts("pets", S))
			t[S]:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("pets", S, t[S]:GetValue()) end)
			YayMountsContent:AddChild(t[S])
		end
		
	else
		for q=1, GetNumCompanions("MOUNT"), 1 do
		local _,_,S,_,_ = GetCompanionInfo("Mount", q)
			if self.db.char.mounts[S][3] == mountType then
				t[S] = AceGUI:Create("CheckBox")
				t[S]:SetImage(self.db.char.mounts[S][2])
				t[S]:SetLabel(self.db.char.mounts[S][1])
				t[S]:SetValue(YayMounts:GetMounts("mounts", S))
				t[S]:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("mounts", S, t[S]:GetValue()) end)
				YayMountsContent:AddChild(t[S])
			end
		end
		
		if mountType == "ground" and IsUsableS(87840) then
			t[87840] = AceGUI:Create("CheckBox")
			t[87840]:SetImage("Interface\\Icons\\ability_mount_blackdirewolf")
			t[87840]:SetLabel(YayMounts:SpellToName(87840))
			t[87840]:SetValue(YayMounts:GetMounts("mounts", 87840))
			t[87840]:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("mounts", 87840, t[87840]:GetValue()) end)
			YayMountsContent:AddChild(t[87840])
		end
	end
end

function YayMounts:SortMounts(tempTable)--Rebuilds the database. Activates on load
	for q=1, GetNumCompanions("MOUNT"), 1 do
		local _,_,S,I,O = GetCompanionInfo("MOUNT", q)
		local N = YayMounts:SpellToName(S)
		local mountType = nil
		for k,v in pairs(YayMountsType["Mounts"]) do
			if S == k then
				mountType = v
			end
		end
		
		if mountType == nil and S ~= 75207 then
			self:Print(YayMountsLocale.String.NewMountFound..""..N)
		else		
			if tempTable[S] == nil then
				self.db.char.mounts[S] = {N, I, mountType, true}
			elseif tempTable[S] == true then
				self.db.char.mounts[S] = {N, I, mountType, true}
			else
				self.db.char.mounts[S] = {N, I, mountType, false}
			end
			self.db.char.settings["HM"] = true
		end
	end
	
	if self.db.char.misc["RACE"] == "Worgen" and UnitLevel("player") >= 20 then
		if self.db.char.mounts[87840] then
			if tempTable[87840] == nil then
				self.db.char.mounts[87840] = {YayMounts:SpellToName(87840), "Interface\\Icons\\ability_mount_blackdirewolf", "ground", true}
			elseif tempTable[87840] == true then
				self.db.char.mounts[87840] = {YayMounts:SpellToName(87840), "Interface\\Icons\\ability_mount_blackdirewolf", "ground", true}
			else
				self.db.char.mounts[87840] = {YayMounts:SpellToName(87840), "Interface\\Icons\\ability_mount_blackdirewolf", "ground", false}
			end
		else
			self.db.char.mounts[87840] = {YayMounts:SpellToName(87840), "Interface\\Icons\\ability_mount_blackdirewolf", "ground", true}
		end
		
		self.db.char.settings["HM"] = true
	end
end
--------------------------------------------------------------
--GUI functions for drawing frames
--------------------------------------------------------------
local function AspectDropdownHandler(widget, aspect1DD, aspect2DD, key, mode)
	if mode == 1 then
		if widget == aspect1DD then
			for q=1, 5, 1 do
				aspect2DD:SetItemDisabled(q, false)
			end		
			aspect2DD:SetItemDisabled(key, true)
			YayMounts.db.char.settings["HA1"] = key
			
		else
			for q=1, 5, 1 do
				aspect1DD:SetItemDisabled(q, false)
			end
			aspect1DD:SetItemDisabled(key, true)
			YayMounts.db.char.settings["HA2"] = key
		end
		
	else		
		if widget == aspect1DD then
			for q=1, 5, 1 do
				aspect2DD:SetItemDisabled(q, false)
			end
			aspect2DD:SetItemDisabled(key, true)
			YayMounts.db.char.settings["SHA1"] = key
		
		else
			for q=1, 5, 1 do
				aspect1DD:SetItemDisabled(q, false)
			end
			aspect1DD:SetItemDisabled(key, true)
			YayMounts.db.char.settings["SHA2"] = key
		end
	end
end

local function AspectDisabler(widget2, widget3, flag)
	widget2:SetDisabled(not flag)
	widget3:SetDisabled(not flag)
end

local function PetOptionsHandler(flag)
	if flag and GetNumCompanions("CRITTER") > 0 then
		YayMounts:RegisterEvent("PLAYER_ENTERING_WORLD", "EventHandler")
	else
		YayMounts:UnregisterEvent("PLAYER_ENTERING_WORLD", "EventHandler")
	end
end

local function DrawGroup1a(container) --Ground Mounts, Tab1
	container:SetLayout("Flow")
		
	local selectallbutton = AceGUI:Create("Button")
	selectallbutton:SetText("Select All")
	selectallbutton:SetCallback("OnClick", function() YayMounts:SelectAllMounts("ground") end)
	container:AddChild(selectallbutton)
		
	local clearallbutton = AceGUI:Create("Button")
	clearallbutton:SetText("Clear All")
	clearallbutton:SetCallback("OnClick", function() YayMounts:ClearMounts("ground") end)
	container:AddChild(clearallbutton)
	
	local scrollcontainerframe = AceGUI:Create("SimpleGroup")
	scrollcontainerframe:SetLayout("Fill")
	scrollcontainerframe:SetFullWidth(true)
	scrollcontainerframe:SetFullHeight(true)
	container:AddChild(scrollcontainerframe)

	local scrollframe = AceGUI:Create("ScrollFrame")
	scrollcontainerframe:AddChild(scrollframe)
	
	YayMountsContent = AceGUI:Create("InlineGroup")
	YayMountsContent:SetFullWidth(true)
 	YayMountsContent:SetLayout("Flow")
	scrollframe:AddChild(YayMountsContent)
	
	YayMounts:BuildList("ground")
end

local function DrawGroup2a(container) --Flying Mounts, Tab2
	container:SetLayout("Flow")
	
	local selectallbutton = AceGUI:Create("Button")
	selectallbutton:SetText("Select All")
	selectallbutton:SetCallback("OnClick", function() YayMounts:SelectAllMounts("fly") end)
	container:AddChild(selectallbutton)
		
	local clearallbutton = AceGUI:Create("Button")
	clearallbutton:SetText("Clear All")
	clearallbutton:SetCallback("OnClick", function() YayMounts:ClearMounts("fly") end)
	container:AddChild(clearallbutton)
	
	local scrollcontainerframe = AceGUI:Create("SimpleGroup")
	scrollcontainerframe:SetLayout("Fill")
	scrollcontainerframe:SetFullWidth(true)
	scrollcontainerframe:SetFullHeight(true)
	container:AddChild(scrollcontainerframe)

	local scrollframe = AceGUI:Create("ScrollFrame")
	scrollcontainerframe:AddChild(scrollframe)
	
	YayMountsContent = AceGUI:Create("InlineGroup")
	YayMountsContent:SetFullWidth(true)
 	YayMountsContent:SetLayout("Flow")
	scrollframe:AddChild(YayMountsContent)
	
	YayMounts:BuildList("fly")
end

local function DrawGroup3a(container) --Scaling Mounts, Tab3
	container:SetLayout("Flow")
	
	local selectallbutton = AceGUI:Create("Button")
	selectallbutton:SetText("Select All")
	selectallbutton:SetCallback("OnClick", function() YayMounts:SelectAllMounts("scaling") end)
	container:AddChild(selectallbutton)
		
	local clearallbutton = AceGUI:Create("Button")
	clearallbutton:SetText("Clear All")
	clearallbutton:SetCallback("OnClick", function() YayMounts:ClearMounts("scaling") end)
	container:AddChild(clearallbutton)
		
	local scrollcontainerframe = AceGUI:Create("SimpleGroup")
	scrollcontainerframe:SetLayout("Fill")
	scrollcontainerframe:SetFullWidth(true)
	scrollcontainerframe:SetFullHeight(true)
	container:AddChild(scrollcontainerframe)
		
	local scrollframe = AceGUI:Create("ScrollFrame")
	scrollcontainerframe:AddChild(scrollframe)
		
	YayMountsContent = AceGUI:Create("InlineGroup")
	YayMountsContent:SetFullWidth(true)
 	YayMountsContent:SetLayout("Flow")
		
	scrollframe:AddChild(YayMountsContent)
	YayMounts:BuildList("scaling")
end

local function DrawGroup4a(container) --Special Mounts, Tab4
	container:SetLayout("Flow")
	
	local selectallbutton = AceGUI:Create("Button")
	selectallbutton:SetText("Select All")
	selectallbutton:SetCallback("OnClick", function() YayMounts:SelectAllMounts("scaling") end)
	container:AddChild(selectallbutton)
		
	local clearallbutton = AceGUI:Create("Button")
	clearallbutton:SetText("Clear All")
	clearallbutton:SetCallback("OnClick", function() YayMounts:ClearMounts("scaling") end)
	container:AddChild(clearallbutton)
		
	local scrollcontainerframe = AceGUI:Create("SimpleGroup")
	scrollcontainerframe:SetLayout("Fill")
	scrollcontainerframe:SetFullWidth(true)
	scrollcontainerframe:SetFullHeight(true)
	container:AddChild(scrollcontainerframe)
		
	local scrollframe = AceGUI:Create("ScrollFrame")
	scrollcontainerframe:AddChild(scrollframe)
		
	YayMountsContent = AceGUI:Create("InlineGroup")
	YayMountsContent:SetFullWidth(true)
 	YayMountsContent:SetLayout("Flow")
		
	scrollframe:AddChild(YayMountsContent)
	YayMounts:BuildList("special")
end

local function SelectGroupMounts(container, event, group)
	container:ReleaseChildren()
	if group == "tab1" then
		DrawGroup1a(container)
	elseif group == "tab2" then
		DrawGroup2a(container)
	elseif group == "tab3" then
		DrawGroup3a(container)
	elseif group == "tab4" then
		DrawGroup4a(container)
	end
	currentSubTab = group
end

local function DrawGroup1(container)-- function that draws the widgets for the 1st tab MOUNTS
	container:SetLayout("Fill")

	local tab  = AceGUI:Create("TabGroup")
	tab:SetLayout("Flow")
	tab:SetTabs({{text="Ground", value="tab1"}, {text="Flying", value="tab2"}, {text="Scaling", value="tab3"}, {text="Special", value="tab4"}})
	tab:SetCallback("OnGroupSelected", SelectGroupMounts)
	
	if currentSubTab ~= nil then
		tab:SelectTab(currentSubTab)
	else
		tab:SelectTab("tab1")
	end
	container:AddChild(tab)
end

local function DrawGroup2(container)-- function that draws the widgets for the 3rd tab MOUNT OPTIONS
	container:SetLayout("Flow")
	
	yayMountsBindingButton = AceGUI:Create("Keybinding")
	yayMountsBindingButton:SetLabel(BINDING_NAME_YAYMOUNTBINDING)
	yayMountsBindingButton:SetKey(GetBindingKey("YAYMOUNTBINDING"))
	yayMountsBindingButton:SetCallback("OnKeyChanged", function() YayMounts:Keybinding(yayMountsBindingButton:GetKey(), 1) end)
	container:AddChild(yayMountsBindingButton)
	
	yayMountsBindingButton2 = AceGUI:Create("Keybinding")
	yayMountsBindingButton2:SetLabel(BINDING_NAME_YAYMOUNTBINDING2)
	yayMountsBindingButton2:SetKey(GetBindingKey("YAYMOUNTBINDING2"))
	yayMountsBindingButton2:SetCallback("OnKeyChanged", function() YayMounts:Keybinding(yayMountsBindingButton2:GetKey(), 2); end)
	container:AddChild(yayMountsBindingButton2)

	local nDWF = AceGUI:Create("CheckBox")
	nDWF:SetLabel(YayMountsLocale.String.NDWF)
	nDWF:SetValue(YayMounts:GetMounts("settings", "NDWF"))
	nDWF:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("settings", "NDWF", nDWF:GetValue()) end)
	nDWF:SetFullWidth(true)
	container:AddChild(nDWF)
	
	local emptyRandom = AceGUI:Create("CheckBox")
	emptyRandom:SetLabel(YayMountsLocale.String.ER)
	emptyRandom:SetValue(YayMounts:GetMounts("settings", "ER"))
	emptyRandom:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("settings", "ER", emptyRandom:GetValue()) end)
	emptyRandom:SetFullWidth(true)
	container:AddChild(emptyRandom)
	
	local remount = AceGUI:Create("CheckBox")
	remount:SetLabel(YayMountsLocale.String.Remount)
	remount:SetValue(YayMounts:GetMounts("settings", "Remount"))
	remount:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "Remount", remount:GetValue()) end)
	remount:SetFullWidth(true)
	container:AddChild(remount)
	
	local forceFlyingMount = AceGUI:Create("CheckBox")
	forceFlyingMount:SetLabel(YayMountsLocale.String.FFM)
	forceFlyingMount:SetValue(YayMounts:GetMounts("settings", "FFM"))
	forceFlyingMount:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "FFM", forceFlyingMount:GetValue()) end)
	forceFlyingMount:SetFullWidth(true)
	container:AddChild(forceFlyingMount)
	
	local scalingMountLimiter = AceGUI:Create("CheckBox")
	scalingMountLimiter:SetLabel(YayMountsLocale.String.SMIFO)
	scalingMountLimiter:SetValue(YayMounts:GetMounts("settings", "SMIFO"))
	scalingMountLimiter:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "SMIFO", scalingMountLimiter:GetValue()) end)
	scalingMountLimiter:SetFullWidth(true)
	container:AddChild(scalingMountLimiter)
	
	if GetItemCount(33176, false) > 0 then
		local flyingBroomPriority = AceGUI:Create("CheckBox")
		if class == "DRUID" then
			flyingBroomPriority:SetLabel(YayMountsLocale.String.FBP)
		else
			flyingBroomPriority:SetLabel(YayMountsLocale.String.FBPD)
		end
		flyingBroomPriority:SetValue(YayMounts:GetMounts("settings", "FBP"))
		flyingBroomPriority:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "FBP", flyingBroomPriority:GetValue()) end)
		flyingBroomPriority:SetFullWidth(true)
		container:AddChild(flyingBroomPriority)
	end
	
	if class == "DRUID" then
		local flightFormPriority = AceGUI:Create("CheckBox")
		flightFormPriority:SetLabel(YayMountsLocale.String.FFP)
		flightFormPriority:SetValue(YayMounts:GetMounts("settings", "FFP"))
		flightFormPriority:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("settings", "FFP", flightFormPriority:GetValue()) end)
		flightFormPriority:SetFullWidth(true)
		container:AddChild(flightFormPriority)
		
		local travelToTravel = AceGUI:Create("CheckBox")
		travelToTravel:SetLabel(YayMountsLocale.String.TTT)
		travelToTravel:SetValue(YayMounts:GetMounts("settings", "TTT"))
		travelToTravel:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "TTT", travelToTravel:GetValue()) end)
		travelToTravel:SetFullWidth(true)
		container:AddChild(travelToTravel)
		
		local mountToFlightForm = AceGUI:Create("CheckBox")
		mountToFlightForm:SetLabel(YayMountsLocale.String.MTFF)
		mountToFlightForm:SetValue(YayMounts:GetMounts("settings", "MTFF"))
		mountToFlightForm:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "MTFF", mountToFlightForm:GetValue()) end)
		mountToFlightForm:SetFullWidth(true)
		container:AddChild(mountToFlightForm)
		
		local catFormIndoors = AceGUI:Create("CheckBox")
		catFormIndoors:SetLabel(YayMountsLocale.String.CFI)
		catFormIndoors:SetValue(YayMounts:GetMounts("settings", "CFI"))
		catFormIndoors:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "CFI", catFormIndoors:GetValue()) end)
		catFormIndoors:SetFullWidth(true)
		container:AddChild(catFormIndoors)
	end
	
	if class == "HUNTER" then
		local aspectInCombat = AceGUI:Create("CheckBox")
		aspectInCombat:SetLabel(YayMountsLocale.String.AIC)
		aspectInCombat:SetValue(YayMounts:GetMounts("settings", "AIC"))
		aspectInCombat:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "AIC", aspectInCombat:GetValue()) end)
		aspectInCombat:SetFullWidth(true)
		container:AddChild(aspectInCombat)
		
		local useAspect = AceGUI:Create("CheckBox")
		useAspect:SetLabel(YayMountsLocale.String.UA)
		useAspect:SetValue(YayMounts:GetMounts("settings", "UA"))
		useAspect:SetFullWidth(true)
		container:AddChild(useAspect)
		
		if YayMounts.db.char.settings["HA1"] == YayMounts.db.char.settings["HA2"] then
			YayMounts.db.char.settings["HA1"] = 1
			YayMounts.db.char.settings["HA2"] = 3
		end
		
		local aspectNamesTable = {}
		for q=1, 5, 1 do
			if IsUsableS(aspectTable[q]) then
				aspectNamesTable[q] = YayMounts:SpellToName(aspectTable[q])
			else
				aspectNamesTable[q] = nil
			end
		end
		
	--Primary Aspects--
		
		local aspectLabel = AceGUI:Create("Label")
		aspectLabel:SetText(YayMountsLocale.String.AL)
		aspectLabel:SetColor(.65, .65, 1)
		aspectLabel:SetFullWidth(true)
		container:AddChild(aspectLabel)
		
		local aspect1DD = AceGUI:Create("Dropdown")
		aspect1DD:SetList(aspectNamesTable)
		aspect1DD:SetLabel("Aspect #1")
		aspect1DD:SetValue(YayMounts.db.char.settings["HA1"])
		container:AddChild(aspect1DD)
		
		local aspect2DD = AceGUI:Create("Dropdown")
		aspect2DD:SetList(aspectNamesTable)
		aspect2DD:SetLabel("Aspect #2")
		aspect2DD:SetValue(YayMounts.db.char.settings["HA2"])
		container:AddChild(aspect2DD)
		
		aspect1DD:SetItemDisabled(YayMounts.db.char.settings["HA2"], true)
		aspect2DD:SetItemDisabled(YayMounts.db.char.settings["HA1"], true)
		
		aspect1DD:SetCallback("OnValueChanged", function(widget, event, key) AspectDropdownHandler(widget, aspect1DD, aspect2DD, key, 1) end)
		aspect2DD:SetCallback("OnValueChanged", function(widget, event, key) AspectDropdownHandler(widget, aspect1DD, aspect2DD, key, 1) end)
		useAspect:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "UA", useAspect:GetValue()) AspectDisabler(aspect1DD, aspect2DD, useAspect:GetValue()) end)
	
	--Secondary Aspects--
	
		local useAspect2 = AceGUI:Create("CheckBox")
		useAspect2:SetLabel(YayMountsLocale.String.UA2)
		useAspect2:SetValue(YayMounts:GetMounts("settings", "UA2"))
		useAspect2:SetFullWidth(true)
		container:AddChild(useAspect2)
		
		local aspectLabel2 = AceGUI:Create("Label")
		aspectLabel2:SetText(AL2)
		aspectLabel2:SetColor(.65, .65, 1)
		aspectLabel2:SetFullWidth(true)
		container:AddChild(aspectLabel2)
		
		local aspectS1DD = AceGUI:Create("Dropdown")
		aspectS1DD:SetList(aspectNamesTable)
		aspectS1DD:SetLabel("Aspect #1")
		aspectS1DD:SetValue(YayMounts.db.char.settings["SHA1"])
		container:AddChild(aspectS1DD)
		
		local aspectS2DD = AceGUI:Create("Dropdown")
		aspectS2DD:SetList(aspectNamesTable)
		aspectS2DD:SetLabel("Aspect #2")
		aspectS2DD:SetValue(YayMounts.db.char.settings["SHA2"])
		container:AddChild(aspectS2DD)
		
		aspectS1DD:SetItemDisabled(YayMounts.db.char.settings["SHA2"], true)
		aspectS2DD:SetItemDisabled(YayMounts.db.char.settings["SHA1"], true)
		
		aspectS1DD:SetCallback("OnValueChanged", function(widget, event, key) AspectDropdownHandler(widget, aspectS1DD, aspectS2DD, key, 2) end)
		aspectS2DD:SetCallback("OnValueChanged", function(widget, event, key) AspectDropdownHandler(widget, aspectS1DD, aspectS2DD, key, 2) end)
		useAspect2:SetCallback("OnValueChanged", function() YayMounts:SetMounts("settings", "UA2", useAspect2:GetValue()) AspectDisabler(aspectS1DD, aspectS2DD, useAspect2:GetValue()) end)
	
	end
	
	if class == "MAGE" then
		local pMLS = AceGUI:Create("CheckBox")
		pMLS:SetLabel(YayMountsLocale.String.MS)
		pMLS:SetValue(YayMounts:GetMounts("settings", "PMLS"))
		pMLS:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("settings", "PMLS", pMLS:GetValue()) end)
		pMLS:SetFullWidth(true)
		container:AddChild(pMLS)
	end
	
	if class == "PRIEST" then
		local pMLS = AceGUI:Create("CheckBox")
		pMLS:SetLabel(YayMountsLocale.String.PL)
		pMLS:SetValue(YayMounts:GetMounts("settings", "PMLS"))
		pMLS:SetCallback("OnValueChanged",  function() YayMounts:SetMounts("settings", "PMLS", pMLS:GetValue()) end)
		pMLS:SetFullWidth(true)
		container:AddChild(pMLS)
	end
end

local function SelectGroup(container, event, group)-- Callback function for OnGroupSelected
	container:ReleaseChildren()
	if group == "tab1" then
		DrawGroup1(container)
 	elseif group == "tab2" then
 		DrawGroup2(container)
	end
	currentTab = group
end

function YayMounts:Frames(selectedTab)-- Basic frame
	if not yayFrame then
		yayFrame = AceGUI:Create("Frame")
		yayFrame:SetCallback("OnClose", function(widget) AceGUI:Release(widget); yayFrame = nil end)
		yayFrame:SetTitle("Yay Mounts")
		yayFrame:SetStatusText("Version "..version..", by Cyrae - Windrunner US")
		yayFrame:SetLayout("Fill")
		yayFrame:SetWidth(720)
		yayFrame:SetHeight(490)
	
		local tab = AceGUI:Create("TabGroup")
		tab:SetLayout("Flow")
		tab:SetTabs({{text="Mounts", value="tab1"}, {text="Mount Options", value="tab2"}})
		tab:SetCallback("OnGroupSelected", SelectGroup)
		tab:SelectTab(selectedTab)
		yayFrame:AddChild(tab)
		
	else
		AceGUI:Release(yayFrame)
		yayFrame, currentTab, currentSubTab = nil
	end
end

--------------------------------------------------------------
--Mounting and button click functions
--------------------------------------------------------------
function YayMounts:Mounting(flyable, zone)
	if self.db.char.settings["HM"] then --fix this for running wild
		local e = {}
		local i = 1
		local mountType
		
		if flyable then
			mountType = "fly"
		else
			mountType = "ground"
		end
		
		--write code to prefer scaling mounts over ground mounts when underwater, unless in vashjir?
		for k,v in pairs(self.db.char.mounts) do
			if self.db.char.settings["SMIFO"] then
				if mountType == "fly" then
					if (v[3] == mountType or v[3] == "scaling") and v[4] then
						e[i] = k
						i = i + 1
					end
					
				else
					if v[3] == mountType and v[4] then
						e[i] = k
						i = i + 1
					end
				end
			
			else
				if (v[3] == mountType or v[3] == "scaling") and v[4] then
					e[i] = k
					i = i + 1
				end
			end
		end
		
		if self.db.char.settings["FFM"] and mountType == "ground" and (IsUsableSpell(61229) or IsUsableSpell(32295)) then
			for k,v in pairs(self.db.char.mounts) do
				if (v[3] == "fly") and v[4] then
					if IsUsableSpell(k) then
						e[i] = k
						i = i + 1
					end
				end
			end
		end
		
		e = YayMounts:Filter(e, zone)
		
		if #e == 0 and self.db.char.settings["ER"] then
			i = 1
			for k,v in pairs(self.db.char.mounts) do
				if IsUsableSpell(k) and (v[3] == mountType or v[3] == "scaling")  then				
					e[i] = k
					i = i + 1
				end
			end
			
			if i == 1 then
				for k,v in pairs(self.db.char.mounts) do
					if IsUsableSpell(k) then				
						e[i] = k
						i = i + 1
					end
				end
			end
			
			e = YayMounts:Filter(e, zone)
		
		elseif #e == 0 then
			self:Print(YayMountsLocale.String.NoMounts)
			return nil
		end
		
		if (flyable or self.db.char.settings["FFM"]) and self.db.char.settings["Remount"] then
			self.db.char.misc["OGM"] = false
		elseif IsOutdoors() and not flyable then
			self.db.char.misc["OGM"] = true
		end
		
		mountUsed = YayMounts:SpellToName(e[math.random(#e)])
		return mountUsed
	end
end

function YayMounts:PreClick()
local _,_,_,_, ghostWolf = GetTalentInfo(2, 6)
local _,_,_,_, feralSwiftness = GetTalentInfo(2, 1)
local _,_,WGActive,_,_,_ = GetWorldPVPAreaInfo(1)
local zone = GetRealZoneText()
local flyable
local broom = false
local loanedMount = nil

	if zone == YayMountsLocale.Zone.Wintergrasp and WGActive then --Check if in wintergrasp and no battle
		flyable = true
	end
	
	--if IsUsableSpell(25528) == 1 or IsUsableSpell(32295) then
	if IsUsableSpell(59976) then
		flyable = true
	else
		flyable = false
	end
	
	loanedMount = YayMounts:CheckMountTraining(zone, loanedMount) --check if we have cold weather flying, a loaned mount, and/or flight master's license

	if ghostwolf == 2 and IsUsableS(2645) then --check if we have instant ghost wolf
		ghostWolf = true
	end
	
	if GetUnitSpeed("player") ~= 0 or IsFalling() or IsFlying() or self.db.char.settings["FBP"] == true then -- check if we can use flying broom
		if GetItemCount(33176, false) > 0 and not playerCombat then
			broom = true
		end
	end
		
	------------Smart mounting stuff-------------

	if IsMounted() and IsFlying() then
		if class == "DRUID" and self.db.char.settings["MTFF"] and IsFlying() and GetUnitSpeed("player") ~= 0 then -- Druid: Flying mount to flight form
			YayMounts:Druids(flyable, zone)
			
		elseif self.db.char.settings["NDWF"] then
			YayMounts:SetMacroButton()
		else
			Dismount()
			YayMounts:SetMacroButton()
		end
	
	elseif IsMounted() then
		if IsSwimming() and class == "DRUID" and IsUsableS(1066) and GetUnitSpeed("player") ~= 0  then
			YayMounts:SetMacroButton(YayMounts:SpellToName(1066)) -- Aquatic Form
			
		elseif self.db.char.settings["Remount"] then  --Stuff for direct ground->flying mounting
			if self.db.char.misc["OGM"] and flyable then
				Dismount()
				self.db.char.misc["OGM"] = false
				if class == "DRUID" then
					YayMounts:Druids(flyable, zone)
				else
					YayMounts:PreClick()
				end
			else
				Dismount()
				YayMounts:SetMacroButton()
			end
			
		else
			Dismount()
			YayMounts:SetMacroButton()
		end
		
	elseif CanExitVehicle() then
		YayMounts:SetMacroButton()
		VehicleExit()
		
	elseif YayMounts:PriestOrMage() then
		return
		
	elseif flyable and IsOutdoors() then
		if class == "SHAMAN" and ghostWolf and (playerCombat or GetUnitSpeed("player") ~= 0) then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645)) --Ghost wolf
			
		elseif IsSwimming() then
			YayMounts:Swimming(flyable, zone, broom)
			
		elseif class == "HUNTER" and GetUnitSpeed("player") ~= 0 and self.db.char.settings["UA"] then
			YayMounts:Hunters(1)
			
		elseif broom then --flying broom
			YayMounts:SetMacroButton(YayMounts:ItemToName(33176))
			
		elseif class == "DRUID" then
			YayMounts:Druids(flyable, zone)
			
		else
			YayMounts:SetMacroButton(YayMounts:Mounting(flyable, zone))
		end
		
	elseif not flyable and IsOutdoors() and zone ~= YayMountsLocale.Zone.VortexPinnacle then
		if zone == YayMountsLocale.Zone.Oculus and YayMounts:Filter(nil, zone) then
			return
			
		elseif class == "SHAMAN" and ghostWolf and (playerCombat or GetUnitSpeed("player") ~= 0) then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645)) --Ghost wolf
			
		elseif class == "SHAMAN" and not self.db.char.settings["HM"] and GetUnitSpeed("player") == 0 then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645))
			
		elseif IsSwimming() then
			YayMounts:Swimming(flyable, zone, broom)
			
		elseif loanedMount ~= nil and not playerCombat and GetUnitSpeed("player") == 0 then
			YayMounts:SetMacroButton(YayMounts:ItemToName(loanedMount))
			
		elseif class == "DRUID" then
			YayMounts:Druids(flyable, zone)
			
		elseif class == "HUNTER" and GetUnitSpeed("player") ~= 0 and self.db.char.settings["UA"] then
			YayMounts:Hunters(1)
			
		else
			YayMounts:SetMacroButton(YayMounts:Mounting(flyable, zone))
		end
		
	elseif not IsOutdoors() or zone == YayMountsLocale.Zone.VortexPinnacle then
		if IsSwimming() then
			YayMounts:Swimming(flyable, zone, broom)
			
		elseif class == "DRUID" and feralSwiftness == 2 and self.db.char.settings["CFI"] then
			YayMounts:SetMacroButton(YayMounts:SpellToName(768))
			
		elseif class == "SHAMAN" and IsUsableS(2645) then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645)) --Ghost wolf
			
		elseif class == "HUNTER" and self.db.char.settings["UA"] then
			YayMounts:Hunters(1)
		end
		
	else
		YayMounts:SetMacroButton(YayMounts:Mounting(flyable, zone))
	end
end

function YayMounts:PriestOrMage()	
	if (IsFalling() or playerCombat or GetUnitSpeed("player") ~= 0) and class == "PRIEST" and IsUsableS(1706) and self.db.char.settings["PMLS"] then --IsUsableSpell checks for reagents/glyphs
		YayMounts:SetMacroButton("[@player] "..YayMounts:SpellToName(1706).."\n/cancelaura "..YayMounts:SpellToName(1706)) --Levitate
		return true
	
	elseif (IsFalling() or playerCombat or GetUnitSpeed("player") ~= 0) and class == "MAGE" and IsUsableS(130) and self.db.char.settings["PMLS"] then
		YayMounts:SetMacroButton("[@player] "..YayMounts:SpellToName(130).."\n/cancelaura "..YayMounts:SpellToName(130)) --Slow fall
		return true
		
	else
		return false
	end
end

function YayMounts:Hunters(button)
	--Primary Aspect Swapping--
	if button == 1 then
		local buff1 = UnitBuff("player", YayMounts:SpellToName(aspectTable[self.db.char.settings["HA1"]]))
		local buff2 = UnitBuff("player", YayMounts:SpellToName(aspectTable[self.db.char.settings["HA2"]]))
			
		if playerCombat and self.db.char.settings["UA"] then
			if buff2 then
				YayMounts:SetMacroButton(""..YayMounts:SpellToName(aspectTable[self.db.char.settings["HA1"]])..", "..YayMounts:SpellToName(aspectTable[self.db.char.settings["HA2"]]).."", 9)
			else
				YayMounts:SetMacroButton(""..YayMounts:SpellToName(aspectTable[self.db.char.settings["HA2"]])..", "..YayMounts:SpellToName(aspectTable[self.db.char.settings["HA1"]]).."", 9)
			end
			
		elseif playerCombat then
			YayMounts:SetMacroButton()
			
		else
			if buff1 then
				YayMounts:SetMacroButton(YayMounts:SpellToName(aspectTable[self.db.char.settings["HA2"]])) --Swap to Aspect 2
			else
				YayMounts:SetMacroButton(YayMounts:SpellToName(aspectTable[self.db.char.settings["HA1"]])) --Swap to Aspect 2 (default)
			end
		end
		
	--Secondary Aspect Swapping--
	elseif button == 2 then
		local buff1 = UnitBuff("player", YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA1"]]))
		local buff2 = UnitBuff("player", YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA2"]]))
			
		if playerCombat and self.db.char.settings["UA"] then
			if buff2 then
				YayMounts:SetMacroButton(""..YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA1"]])..", "..YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA2"]]).."", 8)
			else
				YayMounts:SetMacroButton(""..YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA2"]])..", "..YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA1"]]).."", 8)
			end
			
		elseif playerCombat then
			YayMounts:SetMacroButton()
			
		else
			if buff1 then
				return YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA2"]])
			else
				return YayMounts:SpellToName(aspectTable[self.db.char.settings["SHA1"]])
			end
		end
	end
end

function YayMounts:Druids(flyable, zone)
	local flightForm = 5
	if IsUsableS(24858) or IsUsableS(33891) then
		flightform = 6
	end
	
	if (flyable and not playerCombat) then
		if IsSwimming() then
			YayMounts:SetMacroButton(YayMounts:Mounting(flyable, zone), 1)
		elseif (GetUnitSpeed("player") == 0 and self.db.char.settings["FFP"]) or IsFalling() or IsFlying() or GetUnitSpeed("player") ~= 0 or GetShapeshiftForm() == flightForm then
			if IsUsableS(40120) then --Swift Flight Form
				YayMounts:SetMacroButton(YayMounts:SpellToName(40120))
			elseif IsUsableS(33943) then --Flight Form
				YayMounts:SetMacroButton(YayMounts:SpellToName(33943))
			end
		else
			YayMounts:SetMacroButton(YayMounts:Mounting(flyable, zone), 1)
		end
		
	elseif IsUsableS(783) and (playerCombat or GetUnitSpeed("player") ~= 0) then --Travel Form
		YayMounts:SetMacroButton(YayMounts:SpellToName(783))
		
	elseif not playerCombat then
		YayMounts:SetMacroButton(YayMounts:Mounting(false, zone), 1)	
	end
end

function YayMounts:Swimming(flyable, zone, broom)
	local timer, _,_,scale,_,_ = GetMirrorTimerInfo(2)
	local name, _, _, _, _, _, _, _, _, _, _ = UnitBuff("player", YayMountsLocale.Misc.WaterBreathing)
	if timer == "UNKNOWN" or scale >= 0 then
		scale = 1
	end
	
	if flyable and not playerCombat then
		if class == "DRUID" and IsUsableS(1066) and GetUnitSpeed("player") ~= 0 then
			YayMounts:SetMacroButton(YayMounts:SpellToName(1066)) --Aquatic Form
		elseif class == "DRUID" then
			YayMounts:Druids(flyable, zone)
		--elseif broom then
			--YayMounts:SetMacroButton(YayMounts:ItemToName(33176)) --Flying Broom
		else
			YayMounts:SetMacroButton(YayMounts:Mounting(true, zone))
		end
		
	elseif IsOutdoors() and not playerCombat then
		if class == "DRUID" and IsUsableS(1066) and GetUnitSpeed("player") ~= 0 then
			YayMounts:SetMacroButton(YayMounts:SpellToName(1066)) --Aquatic Form
		else 
			if zone == YayMountsLocale.Zone.Vashjir1 or zone == YayMountsLocale.Zone.Vashjir2 or zone == YayMountsLocale.Zone.Vashjir3 or zone == YayMountsLocale.Zone.Vashjir4 or zone == YayMountsLocale.Zone.Vashjir5 and self.db.char.mounts[75207][4] == true then --Abyssal Seahorse
				YayMounts:SetMacroButton(YayMounts:SpellToName(75207)) --Abyssal Seahorse
			elseif IsUsableSpell(98718) and self.db.char.mounts[98718][4] == true then
				YayMounts:SetMacroButton(YayMounts:SpellToName(98718)) --Subdued Seahorse
			elseif IsUsableM(64731) and self.db.char.mounts[64731][4] then
				YayMounts:SetMacroButton(YayMounts:SpellToName(64731)) --Sea Turtle
			else
				YayMounts:SetMacroButton(YayMounts:Mounting(false, zone))
			end
		end
		
	elseif not playerCombat then
		if class == "DRUID" and IsUsableS(1066) then
			YayMounts:SetMacroButton(YayMounts:SpellToName(1066)) -- Aquatic Form
		elseif class == "SHAMAN" and IsUsableS(2645) then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645)) --Ghost wolf
		end
	end
end

function YayMounts:CheckMountTraining(zone, loanedMount)
	if zone == YayMountsLocale.Zone.StormPeaks or zone == YayMountsLocale.Zone.Icecrown then
		if GetItemCount(44221, false) > 0 then
			return 44221
		elseif GetItemCount(44229, false) > 0 then
			return 44229
		else
			return nil
		end
	end
	return loanedMount, flyable
end

function YayMounts:SetMacroButton(mount, button)
	if not playerCombat then
		if mount and button == 2 then
			if class == "HUNTER" and playerCombat then
				return
			elseif class == "HUNTER" and GetUnitSpeed("player") ~= 0 and self.db.char.settings["UA2"] then
				YayMountsButton2:SetAttribute("macrotext", "/use "..YayMounts:Hunters(button))
			else
				YayMountsButton2:SetAttribute("macrotext", "/use "..YayMounts:Mounting(false, GetRealZoneText()))
			end
		elseif mount and button == 3 then
			YayMountsButton3:SetAttribute("macrotext", "/use "..mount)
		elseif mount and button == 8 then --hunter secondary castsequence
			YayMountsButton2:SetAttribute("macrotext", "/castsequence "..mount)
		elseif mount and button == 9 then --hunter castsequence macro
			YayMountsButton:SetAttribute("macrotext", "/castsequence "..mount)
		elseif mount then
			YayMountsButton:SetAttribute("macrotext", "/use "..mount)
		else
			YayMountsButton:SetAttribute("macrotext", nil)
		end
	end
end

function YayMounts:Filter(e, zone)
	if zone ~= YayMountsLocale.Zone.AQ40 and e ~= nil then
		for k,v in pairs(e) do
			if v == YayMountsType["Ahn'Qiraj"][v] then
				tremove(e, k)
			end
		end
		return e
		
	elseif zone == YayMountsLocale.Zone.AQ40 and e ~= nil then
		local aq40 = false
		local aq40Table = {}
		local i = 1
		
		for k,v in pairs(e) do
			if v == YayMountsType["Ahn'Qiraj"][v] then
				aq40 = true
				
				break
			end
		end
		
		if aq40 then
			for k,v in pairs(e) do
				if v == YayMountsType["Ahn'Qiraj"][v] then
					aq40Table[i] = v
					i = i + 1
				end
			end
			return aq40Table
		
		else
			return e
		end
		
	
	elseif zone == YayMountsLocale.Zone.Oculus and e == nil then
		if GetItemCount(37859) == 1 then
			YayMounts:SetMacroButton(YayMounts:ItemToName(37859))
			return true
		elseif GetItemCount(37860) == 1 then
			YayMounts:SetMacroButton(YayMounts:ItemToName(37860))
			return true
		elseif GetItemCount(37815) == 1 then
			YayMounts:SetMacroButton(YayMounts:ItemToName(37815))
			return true
		end
		return false
		
	else
		return e
	end
end

function YayMounts:EventHandler(arg1, arg2)
	if  arg1 == "PLAYER_REGEN_DISABLED" then
		playerCombat = true
		if class == "SHAMAN" then
			YayMounts:SetMacroButton(YayMounts:SpellToName(2645))
		elseif class == "DRUID" then
			if not self.db.char.settings["TTT"] then
				YayMounts:SetMacroButton("[swimming] "..YayMounts:SpellToName(1066).."; "..YayMounts:SpellToName(783))
			else
				YayMounts:SetMacroButton("[swimming] !"..YayMounts:SpellToName(1066).."; !"..YayMounts:SpellToName(783))
			end
		elseif class == "HUNTER" and self.db.char.settings["AIC"] then
			YayMounts:Hunters(1)
			YayMounts:Hunters(2)
		elseif class == "MAGE" or class == "PRIEST" then
			YayMounts:PriestOrMage()
		end
		
	elseif arg1 == "PLAYER_REGEN_ENABLED" then
		playerCombat = false
		YayMounts:SetMacroButton()
		
	elseif arg1 == "PLAYER_LEVEL_UP" then
		if arg2 == 20 then
			YayMounts:ReSort()
			self:UnregisterEvent("PLAYER_LEVEL_UP")
		end
		
	elseif arg1 == "COMPANION_LEARNED" then
		YayMounts:ReSort()
		if yayFrame then
			local ct, cst = currentTab, currentSubTab
			YayMounts:Frames()
			currentSubTab = cst
			YayMounts:Frames(ct)
		end
	end
end

--------------------------------------------------------------
--Keybinding stuff
--------------------------------------------------------------
function YayMounts:MapOverrides()
	if not InCombatLockdown() then
		ClearOverrideBindings(YayMountsButton)
		local key1 = GetBindingKey("YAYMOUNTBINDING")
		if key1 then
			SetOverrideBindingClick(YayMountsButton, true, key1, YayMountsButton:GetName())
		end

		ClearOverrideBindings(YayMountsButton2)
		key1 = GetBindingKey("YAYMOUNTBINDING2")
		if key1 then
			SetOverrideBindingClick(YayMountsButton2, true, key1, YayMountsButton2:GetName())
		end
	end
end

function YayMounts:Keybinding(key, buttonID)
	if not key then
		key = ""
	end

	if not InCombatLockdown() then
		if buttonID == 1 then
			local key1 = GetBindingKey("YAYMOUNTBINDING")
			if key1 then
				SetBinding(key1)
			end
			SetBinding(key, "YAYMOUNTBINDING")
			
		elseif buttonID == 2 then
			local key1 = GetBindingKey("YAYMOUNTBINDING2")
			if key1 then
				SetBinding(key1)
			end
			SetBinding(key, "YAYMOUNTBINDING2")
		end
	end	
	
	SaveBindings(GetCurrentBindingSet())
end